import 'node-forge/lib/pkcs7.js';
import 'node-forge/lib/pbe.js';
import type { KeyChain } from './index.js';
/**
 * Cryptographic Message Syntax (aka PKCS #7)
 *
 * CMS describes an encapsulation syntax for data protection. It
 * is used to digitally sign, digest, authenticate, or encrypt
 * arbitrary message content.
 *
 * See RFC 5652 for all the details.
 */
export declare class CMS {
    private readonly keychain;
    /**
     * Creates a new instance with a keychain
     */
    constructor(keychain: KeyChain, dek: string);
    /**
     * Creates some protected data.
     *
     * The output Uint8Array contains the PKCS #7 message in DER.
     */
    encrypt(name: string, plain: Uint8Array): Promise<Uint8Array>;
    /**
     * Reads some protected data.
     *
     * The keychain must contain one of the keys used to encrypt the data.  If none of the keys
     * exists, an Error is returned with the property 'missingKeys'.  It is array of key ids.
     */
    decrypt(cmsData: Uint8Array): Promise<Uint8Array>;
}
//# sourceMappingURL=cms.d.ts.map